==> tuyaos_demo_ipc_1.0.0.tar.gz: tuyaos_demo_ipc/include/tuya_ipc_p2p_demo.h <==
/*
 * tuya_ipc_p2p_demo.h 
 *  Created on: 2020年5月19日
 *      Author: 02426
 * Copyright(C),2018-2020, 涂鸦科技 www.tuya.comm
 */

#ifndef __TUYA_IPC_P2P_DEMO_H__
#define __TUYA_IPC_P2P_DEMO_H__
#include<stdbool.h>
#include "tuya_ipc_p2p.h"
#include "tuya_os_adapter.h"
#include "tuya_ipc_media_adapter.h"
#include "tuya_ipc_media_demo.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct
{
	BOOL_T enable; /*enable == false ,other var is invalid*/
	UINT_T max_stream_client; /* stream clinet max connect number*/
    TRANS_DEFAULT_QUALITY_E live_mode;  /* for multi-streaming ipc, the default quality for live preview */
	MEDIA_STREAM_EVENT_CB media_event_cb; /*media event callback*/
	MEDIA_RECV_AUDIO_CB rev_audio_cb;/*app to dev audio callback*/
    MEDIA_RECV_VIDEO_CB rev_video_cb;/*app to dev audio callback*/
    MEDIA_RECV_FILE_CB rev_file_cb;/*app to dev file callback*/
    MEDIA_GET_SNAPSHOT_CB get_snapshot_cb;
}TUYA_IPC_SDK_MEDIA_ADAPTER_S;

VOID __TUYA_APP_rev_audio_cb(IN INT_T device, IN INT_T channel,IN CONST MEDIA_AUDIO_FRAME_T *p_audio_frame, IN CONST UINT_T frame_no);
INT_T __TUYA_APP_p2p_event_cb(IN CONST INT_T device, IN CONST INT_T channel, IN CONST MEDIA_STREAM_EVENT_E event, IN PVOID_T args);
VOID __TUYA_APP_rev_video_cb(IN INT_T device, IN INT_T channel, IN CONST MEDIA_VIDEO_FRAME_T *p_video_frame);
VOID __TUYA_APP_rev_file_cb(IN INT_T device, IN INT_T channel, IN CONST MEDIA_FILE_DATA_T *p_file_data);

VOID IPC_APP_Media_Adapter_Init(TUYA_IPC_SDK_MEDIA_ADAPTER_S *p_media_adatper_info, TUYA_IPC_SDK_MEDIA_STREAM_S *p_media_infos);
VOID IPC_APP_Media_Stream_Init(TUYA_IPC_SDK_MEDIA_ADAPTER_S *p_media_adatper_info);
void *thread_album_send(void *arg);
void demo_test_push_file();

#ifdef __cplusplus
}
#endif
#endif /* __TUYA_IPC_P2P_DEMO_H__ */

==> tuyaos_demo_ipc_1.0.10.tar.gz: tuyaos_demo_ipc/include/tuya_ipc_p2p_demo.h <==
/*
 * tuya_ipc_p2p_demo.h 
 *  Created on: 2020年5月19日
 *      Author: 02426
 * Copyright(C),2018-2020, 涂鸦科技 www.tuya.comm
 */

#ifndef __TUYA_IPC_P2P_DEMO_H__
#define __TUYA_IPC_P2P_DEMO_H__
#include<stdbool.h>
#include "tuya_ipc_p2p.h"
#include "tuya_os_adapter.h"
#include "tuya_ipc_media_adapter.h"
#include "tuya_ipc_media_demo.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct
{
	BOOL_T enable; /*enable == false ,other var is invalid*/
	UINT_T max_stream_client; /* stream clinet max connect number*/
    TRANS_DEFAULT_QUALITY_E live_mode;  /* for multi-streaming ipc, the default quality for live preview */
	MEDIA_STREAM_EVENT_CB media_event_cb; /*media event callback*/
	MEDIA_RECV_AUDIO_CB rev_audio_cb;/*app to dev audio callback*/
    MEDIA_RECV_VIDEO_CB rev_video_cb;/*app to dev audio callback*/
    MEDIA_RECV_FILE_CB rev_file_cb;/*app to dev file callback*/
    MEDIA_GET_SNAPSHOT_CB get_snapshot_cb;
}TUYA_IPC_SDK_MEDIA_ADAPTER_S;

VOID __TUYA_APP_rev_audio_cb(IN INT_T device, IN INT_T channel, IN CONST MEDIA_AUDIO_FRAME_T *p_audio_frame);
INT_T __TUYA_APP_p2p_event_cb(IN CONST INT_T device, IN CONST INT_T channel, IN CONST MEDIA_STREAM_EVENT_E event, IN PVOID_T args);
VOID __TUYA_APP_rev_video_cb(IN INT_T device, IN INT_T channel, IN CONST MEDIA_VIDEO_FRAME_T *p_video_frame);
VOID __TUYA_APP_rev_file_cb(IN INT_T device, IN INT_T channel, IN CONST MEDIA_FILE_DATA_T *p_file_data);

VOID IPC_APP_Media_Adapter_Init(TUYA_IPC_SDK_MEDIA_ADAPTER_S *p_media_adatper_info, TUYA_IPC_SDK_MEDIA_STREAM_S *p_media_infos);
VOID IPC_APP_Media_Stream_Init(TUYA_IPC_SDK_MEDIA_ADAPTER_S *p_media_adatper_info);
void *thread_album_send(void *arg);
void demo_test_push_file();

#ifdef __cplusplus
}
#endif
#endif /* __TUYA_IPC_P2P_DEMO_H__ */
